@@ -10,5 +10,6 @@ colors = Fore
 class coloredPrint():
     def print(self, textToPrint, color=None):
         if (color == None):
-            raise ValueError(f"{colors.RED}Color can't be None{colors.RESET}")
+            print(f"{colors.RED}")
+            raise ValueError(f"Color can't be None{colors.RESET}")
         print(f"{color}{textToPrint}{colors.RESET}")
